self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "5988b1678eae721ea4bab7670a308411",
    "url": "./index.html"
  },
  {
    "revision": "57549d7f7cdfa1b4319e",
    "url": "./static/js/2.27bd71cc.chunk.js"
  },
  {
    "revision": "3dc2da520b7611f998bec3f8b32ee24e",
    "url": "./static/js/2.27bd71cc.chunk.js.LICENSE.txt"
  },
  {
    "revision": "7a2e789bf6de98100e4c",
    "url": "./static/js/main.804ec37d.chunk.js"
  },
  {
    "revision": "b6fdd73ea308285c3bb7",
    "url": "./static/js/runtime-main.b42ca973.js"
  }
]);